Trace Rest API
==============

**Overview**

.. qrefflask:: rucio.web.rest.flaskapi.v1.traces:make_doc()
     :undoc-static:

**Details**
     
.. autoflask:: rucio.web.rest.flaskapi.v1.traces:make_doc()
     :undoc-static:
